//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Mask/SceneAdaptor.cpp
//! @brief     Implements class SceneAdaptor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Mask/SceneAdaptor.h"
#include "GUI/View/PlotScale/ColorMap.h"
#include <QEvent>

SceneAdaptor::SceneAdaptor()
    : m_plot(nullptr)
{
}

qreal SceneAdaptor::toSceneX(qreal mask_x) const
{
    return m_plot ? m_plot->xAxisCoordToPixel(mask_x) : mask_x;
}

qreal SceneAdaptor::toSceneY(qreal mask_y) const
{
    return m_plot ? m_plot->yAxisCoordToPixel(mask_y) : mask_y;
}

qreal SceneAdaptor::fromSceneX(qreal scene_x) const
{
    return m_plot ? m_plot->pixelToXaxisCoord(scene_x) : scene_x;
}

qreal SceneAdaptor::fromSceneY(qreal scene_y) const
{
    return m_plot ? m_plot->pixelToYaxisCoord(scene_y) : scene_y;
}

void SceneAdaptor::setColorMapPlot(ColorMap* plot)
{
    m_plot = plot;
    if (m_plot)
        m_plot->installEventFilter(this);
}

bool SceneAdaptor::eventFilter(QObject* object, QEvent* event)
{
    Q_UNUSED(object);
    if (event->type() == QEvent::Resize || event->type() == QEvent::UpdateRequest) {
        m_viewport_rectangle = m_plot->viewportRectangleInWidgetCoordinates();
        emit update_request();
        return false;
    }
    return true;
}
